pub enum DriverIndexRequest {
MatchDriver {
args: MatchDriverArgs,
responder: DriverIndexMatchDriverResponder,
},
AddCompositeNodeSpec {
payload: CompositeNodeSpec,
responder: DriverIndexAddCompositeNodeSpecResponder,
},
RebindCompositeNodeSpec {
spec: String,
driver_url_suffix: Option<String>,
responder: DriverIndexRebindCompositeNodeSpecResponder,
},
MatchPendingNode {
dependencies: Vec<ParentSpec2>,
responder: DriverIndexMatchPendingNodeResponder,
},
SetNotifier {
notifier: ClientEnd<DriverNotifierMarker>,
control_handle: DriverIndexControlHandle,
},
}Expand description
Protocol through which the driver index can be queried.
Variants
MatchDriver
Match a set of device arguments to a driver package URL.
AddCompositeNodeSpec
Adds a composite node spec to the driver index. The driver index stores the composite node spec and maps it by the name. The stored composite node specs are included in the driver matching process.
RebindCompositeNodeSpec
Rematch the composite node spec to a composite driver. If a driver url suffix is provided, the composite node spec will only be matched against drivers with URLS that end with the suffix.
Fields
responder: DriverIndexRebindCompositeNodeSpecResponderMatchPendingNode
Match a pending node to a composite driver. Since the driver-index doesn’t store pending nodes, this only attempts to match the pending node details against the registered composite drivers.
SetNotifier
Sets the DriverNotifier which is used for reverse communication.
Implementations
Sourceimpl DriverIndexRequest
impl DriverIndexRequest
pub fn into_match_driver( self, ) -> Option<(MatchDriverArgs, DriverIndexMatchDriverResponder)>
pub fn into_add_composite_node_spec( self, ) -> Option<(CompositeNodeSpec, DriverIndexAddCompositeNodeSpecResponder)>
pub fn into_rebind_composite_node_spec( self, ) -> Option<(String, Option<String>, DriverIndexRebindCompositeNodeSpecResponder)>
pub fn into_match_pending_node( self, ) -> Option<(Vec<ParentSpec2>, DriverIndexMatchPendingNodeResponder)>
pub fn into_set_notifier( self, ) -> Option<(ClientEnd<DriverNotifierMarker>, DriverIndexControlHandle)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL