pub struct DriverIndexMatchPendingNodeRequest {
pub dependencies: Vec<ParentSpec2>,
}Fields
dependencies: Vec<ParentSpec2>Trait Implementations
Sourceimpl Clone for DriverIndexMatchPendingNodeRequest
impl Clone for DriverIndexMatchPendingNodeRequest
Sourcefn clone(&self) -> DriverIndexMatchPendingNodeRequest
fn clone(&self) -> DriverIndexMatchPendingNodeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<DriverIndexMatchPendingNodeRequest, D> for DriverIndexMatchPendingNodeRequestwhere
D: ResourceDialect,
impl<D> Decode<DriverIndexMatchPendingNodeRequest, D> for DriverIndexMatchPendingNodeRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> DriverIndexMatchPendingNodeRequest
fn new_empty() -> DriverIndexMatchPendingNodeRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<DriverIndexMatchPendingNodeRequest, D> for &DriverIndexMatchPendingNodeRequestwhere
D: ResourceDialect,
impl<D> Encode<DriverIndexMatchPendingNodeRequest, D> for &DriverIndexMatchPendingNodeRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for DriverIndexMatchPendingNodeRequest
impl PartialEq for DriverIndexMatchPendingNodeRequest
Sourcefn eq(&self, other: &DriverIndexMatchPendingNodeRequest) -> bool
fn eq(&self, other: &DriverIndexMatchPendingNodeRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for DriverIndexMatchPendingNodeRequest
impl StructuralPartialEq for DriverIndexMatchPendingNodeRequest
Sourceimpl TypeMarker for DriverIndexMatchPendingNodeRequest
impl TypeMarker for DriverIndexMatchPendingNodeRequest
Sourcetype Owned = DriverIndexMatchPendingNodeRequest
type Owned = DriverIndexMatchPendingNodeRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DriverIndexMatchPendingNodeRequest
impl ValueTypeMarker for DriverIndexMatchPendingNodeRequest
Sourcetype Borrowed<'a> = &'a DriverIndexMatchPendingNodeRequest
type Borrowed<'a> = &'a DriverIndexMatchPendingNodeRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<DriverIndexMatchPendingNodeRequest as TypeMarker>::Owned,
) -> <DriverIndexMatchPendingNodeRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<DriverIndexMatchPendingNodeRequest as TypeMarker>::Owned, ) -> <DriverIndexMatchPendingNodeRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for DriverIndexMatchPendingNodeRequest
impl RefUnwindSafe for DriverIndexMatchPendingNodeRequest
impl Send for DriverIndexMatchPendingNodeRequest
impl Sync for DriverIndexMatchPendingNodeRequest
impl Unpin for DriverIndexMatchPendingNodeRequest
impl UnsafeUnpin for DriverIndexMatchPendingNodeRequest
impl UnwindSafe for DriverIndexMatchPendingNodeRequest