pub struct DriverIndexProxy { /* private fields */ }Implementations
Sourceimpl DriverIndexProxy
impl DriverIndexProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.driver.index/DriverIndex.
Sourcepub fn take_event_stream(&self) -> DriverIndexEventStream
pub fn take_event_stream(&self) -> DriverIndexEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn match_driver(
&self,
args: &MatchDriverArgs,
) -> QueryResponseFut<DriverIndexMatchDriverResult, DefaultFuchsiaResourceDialect>
pub fn match_driver( &self, args: &MatchDriverArgs, ) -> QueryResponseFut<DriverIndexMatchDriverResult, DefaultFuchsiaResourceDialect>
Match a set of device arguments to a driver package URL.
Sourcepub fn add_composite_node_spec(
&self,
payload: &CompositeNodeSpec,
) -> QueryResponseFut<DriverIndexAddCompositeNodeSpecResult, DefaultFuchsiaResourceDialect>
pub fn add_composite_node_spec( &self, payload: &CompositeNodeSpec, ) -> QueryResponseFut<DriverIndexAddCompositeNodeSpecResult, DefaultFuchsiaResourceDialect>
Adds a composite node spec to the driver index. The driver index stores the composite node spec and maps it by the name. The stored composite node specs are included in the driver matching process.
Sourcepub fn rebind_composite_node_spec(
&self,
spec: &str,
driver_url_suffix: Option<&str>,
) -> QueryResponseFut<DriverIndexRebindCompositeNodeSpecResult, DefaultFuchsiaResourceDialect>
pub fn rebind_composite_node_spec( &self, spec: &str, driver_url_suffix: Option<&str>, ) -> QueryResponseFut<DriverIndexRebindCompositeNodeSpecResult, DefaultFuchsiaResourceDialect>
Rematch the composite node spec to a composite driver. If a driver url suffix is provided, the composite node spec will only be matched against drivers with URLS that end with the suffix.
Sourcepub fn match_pending_node(
&self,
dependencies: &[ParentSpec2],
) -> QueryResponseFut<DriverIndexMatchPendingNodeResult, DefaultFuchsiaResourceDialect>
pub fn match_pending_node( &self, dependencies: &[ParentSpec2], ) -> QueryResponseFut<DriverIndexMatchPendingNodeResult, DefaultFuchsiaResourceDialect>
Match a pending node to a composite driver. Since the driver-index doesn’t store pending nodes, this only attempts to match the pending node details against the registered composite drivers.
Sourcepub fn set_notifier(
&self,
notifier: ClientEnd<DriverNotifierMarker>,
) -> Result<(), Error>
pub fn set_notifier( &self, notifier: ClientEnd<DriverNotifierMarker>, ) -> Result<(), Error>
Sets the DriverNotifier which is used for reverse communication.