pub struct DriverIndexSynchronousProxy { /* private fields */ }Implementations
Sourceimpl DriverIndexSynchronousProxy
impl DriverIndexSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<DriverIndexEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DriverIndexEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn match_driver(
&self,
args: &MatchDriverArgs,
___deadline: MonotonicInstant,
) -> Result<DriverIndexMatchDriverResult, Error>
pub fn match_driver( &self, args: &MatchDriverArgs, ___deadline: MonotonicInstant, ) -> Result<DriverIndexMatchDriverResult, Error>
Match a set of device arguments to a driver package URL.
Sourcepub fn add_composite_node_spec(
&self,
payload: &CompositeNodeSpec,
___deadline: MonotonicInstant,
) -> Result<DriverIndexAddCompositeNodeSpecResult, Error>
pub fn add_composite_node_spec( &self, payload: &CompositeNodeSpec, ___deadline: MonotonicInstant, ) -> Result<DriverIndexAddCompositeNodeSpecResult, Error>
Adds a composite node spec to the driver index. The driver index stores the composite node spec and maps it by the name. The stored composite node specs are included in the driver matching process.
Sourcepub fn rebind_composite_node_spec(
&self,
spec: &str,
driver_url_suffix: Option<&str>,
___deadline: MonotonicInstant,
) -> Result<DriverIndexRebindCompositeNodeSpecResult, Error>
pub fn rebind_composite_node_spec( &self, spec: &str, driver_url_suffix: Option<&str>, ___deadline: MonotonicInstant, ) -> Result<DriverIndexRebindCompositeNodeSpecResult, Error>
Rematch the composite node spec to a composite driver. If a driver url suffix is provided, the composite node spec will only be matched against drivers with URLS that end with the suffix.
Sourcepub fn match_pending_node(
&self,
dependencies: &[ParentSpec2],
___deadline: MonotonicInstant,
) -> Result<DriverIndexMatchPendingNodeResult, Error>
pub fn match_pending_node( &self, dependencies: &[ParentSpec2], ___deadline: MonotonicInstant, ) -> Result<DriverIndexMatchPendingNodeResult, Error>
Match a pending node to a composite driver. Since the driver-index doesn’t store pending nodes, this only attempts to match the pending node details against the registered composite drivers.
Sourcepub fn set_notifier(
&self,
notifier: ClientEnd<DriverNotifierMarker>,
) -> Result<(), Error>
pub fn set_notifier( &self, notifier: ClientEnd<DriverNotifierMarker>, ) -> Result<(), Error>
Sets the DriverNotifier which is used for reverse communication.